# coding: utf-8

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 0.12.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import onepanel.core.api
from onepanel.core.api.api.auth_service_api import AuthServiceApi  # noqa: E501
from onepanel.core.api.rest import ApiException


class TestAuthServiceApi(unittest.TestCase):
    """AuthServiceApi unit test stubs"""

    def setUp(self):
        self.api = onepanel.core.api.api.auth_service_api.AuthServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_is_authorized(self):
        """Test case for is_authorized

        """
        pass

    def test_is_valid_token(self):
        """Test case for is_valid_token

        """
        pass


if __name__ == '__main__':
    unittest.main()
