# coding: utf-8

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 0.12.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import onepanel.core.api
from onepanel.core.api.api.cron_workflow_service_api import CronWorkflowServiceApi  # noqa: E501
from onepanel.core.api.rest import ApiException


class TestCronWorkflowServiceApi(unittest.TestCase):
    """CronWorkflowServiceApi unit test stubs"""

    def setUp(self):
        self.api = onepanel.core.api.api.cron_workflow_service_api.CronWorkflowServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_cron_workflow(self):
        """Test case for create_cron_workflow

        """
        pass

    def test_delete_cron_workflow(self):
        """Test case for delete_cron_workflow

        """
        pass

    def test_get_cron_workflow(self):
        """Test case for get_cron_workflow

        """
        pass

    def test_list_cron_workflows(self):
        """Test case for list_cron_workflows

        """
        pass

    def test_list_cron_workflows2(self):
        """Test case for list_cron_workflows2

        """
        pass

    def test_update_cron_workflow(self):
        """Test case for update_cron_workflow

        """
        pass


if __name__ == '__main__':
    unittest.main()
