from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from onepanel.core.api.api.auth_service_api import AuthServiceApi
from onepanel.core.api.api.config_service_api import ConfigServiceApi
from onepanel.core.api.api.cron_workflow_service_api import CronWorkflowServiceApi
from onepanel.core.api.api.label_service_api import LabelServiceApi
from onepanel.core.api.api.namespace_service_api import NamespaceServiceApi
from onepanel.core.api.api.secret_service_api import SecretServiceApi
from onepanel.core.api.api.service_service_api import ServiceServiceApi
from onepanel.core.api.api.workflow_service_api import WorkflowServiceApi
from onepanel.core.api.api.workflow_template_service_api import WorkflowTemplateServiceApi
from onepanel.core.api.api.workspace_service_api import WorkspaceServiceApi
from onepanel.core.api.api.workspace_template_service_api import WorkspaceTemplateServiceApi
