# coding: utf-8

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 0.12.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import onepanel.core.api
from onepanel.core.api.api.workflow_template_service_api import WorkflowTemplateServiceApi  # noqa: E501
from onepanel.core.api.rest import ApiException


class TestWorkflowTemplateServiceApi(unittest.TestCase):
    """WorkflowTemplateServiceApi unit test stubs"""

    def setUp(self):
        self.api = onepanel.core.api.api.workflow_template_service_api.WorkflowTemplateServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_archive_workflow_template(self):
        """Test case for archive_workflow_template

        """
        pass

    def test_clone_workflow_template(self):
        """Test case for clone_workflow_template

        """
        pass

    def test_clone_workflow_template2(self):
        """Test case for clone_workflow_template2

        """
        pass

    def test_create_workflow_template(self):
        """Test case for create_workflow_template

        """
        pass

    def test_create_workflow_template_version(self):
        """Test case for create_workflow_template_version

        """
        pass

    def test_get_workflow_template(self):
        """Test case for get_workflow_template

        """
        pass

    def test_get_workflow_template2(self):
        """Test case for get_workflow_template2

        """
        pass

    def test_list_workflow_template_versions(self):
        """Test case for list_workflow_template_versions

        """
        pass

    def test_list_workflow_templates(self):
        """Test case for list_workflow_templates

        """
        pass


if __name__ == '__main__':
    unittest.main()
